orion.primitives.timeseries\_errors.reconstruction\_errors
==========================================================

.. currentmodule:: orion.primitives.timeseries_errors

.. autofunction:: reconstruction_errors